Struct include_graph::dependencies::compiledb::SourceFileEntry
source · pub struct SourceFileEntry {
pub file_path: PathBuf,
pub include_directories: Vec<PathBuf>,
}Fields
file_path: PathBufinclude_directories: Vec<PathBuf>Trait Implementations
sourceimpl Debug for SourceFileEntry
impl Debug for SourceFileEntry
sourceimpl<'de> Deserialize<'de> for SourceFileEntry
impl<'de> Deserialize<'de> for SourceFileEntry
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Hash for SourceFileEntry
impl Hash for SourceFileEntry
sourceimpl PartialEq for SourceFileEntry
impl PartialEq for SourceFileEntry
sourcefn eq(&self, other: &SourceFileEntry) -> bool
fn eq(&self, other: &SourceFileEntry) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for SourceFileEntry
impl PartialOrd for SourceFileEntry
sourcefn partial_cmp(&self, other: &SourceFileEntry) -> Option<Ordering>
fn partial_cmp(&self, other: &SourceFileEntry) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl Serialize for SourceFileEntry
impl Serialize for SourceFileEntry
impl StructuralPartialEq for SourceFileEntry