Struct include_graph::dependencies::graph::Group
source · pub struct Group {
pub name: String,
pub zoomed: bool,
pub color: String,
pub nodes: HashSet<MappedNode>,
}Expand description
A group of related items.
MAY also be a singular item inside, however a graph is generally a group of named items
Fields
name: Stringnice display name
zoomed: boolIf this groop is zoomed in
color: Stringnodes: HashSet<MappedNode>what are the nodes
Implementations