Struct include_graph::dependencies::graph::MappedNode
source · pub struct MappedNode {
pub id: String,
pub path: PathBuf,
pub display_name: String,
}Fields
id: Stringpath: PathBufdisplay_name: StringTrait Implementations
sourceimpl Debug for MappedNode
impl Debug for MappedNode
sourceimpl Hash for MappedNode
impl Hash for MappedNode
sourceimpl Ord for MappedNode
impl Ord for MappedNode
sourcefn cmp(&self, other: &MappedNode) -> Ordering
fn cmp(&self, other: &MappedNode) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for MappedNode
impl PartialEq for MappedNode
sourcefn eq(&self, other: &MappedNode) -> bool
fn eq(&self, other: &MappedNode) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for MappedNode
impl PartialOrd for MappedNode
sourcefn partial_cmp(&self, other: &MappedNode) -> Option<Ordering>
fn partial_cmp(&self, other: &MappedNode) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl Serialize for MappedNode
impl Serialize for MappedNode
impl Eq for MappedNode
impl StructuralPartialEq for MappedNode