Struct include_graph::dependencies::path_mapper::PathMapping
source · pub struct PathMapping {
pub from: PathBuf,
pub to: String,
}Fields
from: PathBufto: StringTrait Implementations
sourceimpl Clone for PathMapping
impl Clone for PathMapping
sourcefn clone(&self) -> PathMapping
fn clone(&self) -> PathMapping
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for PathMapping
impl Debug for PathMapping
sourceimpl Hash for PathMapping
impl Hash for PathMapping
sourceimpl Ord for PathMapping
impl Ord for PathMapping
sourcefn cmp(&self, other: &PathMapping) -> Ordering
fn cmp(&self, other: &PathMapping) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for PathMapping
impl PartialEq for PathMapping
sourcefn eq(&self, other: &PathMapping) -> bool
fn eq(&self, other: &PathMapping) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for PathMapping
impl PartialOrd for PathMapping
sourcefn partial_cmp(&self, other: &PathMapping) -> Option<Ordering>
fn partial_cmp(&self, other: &PathMapping) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Eq for PathMapping
impl StructuralPartialEq for PathMapping